==> chromium-browser_13.0.782.220~r99552.orig.tar.bz2: chromium-13.0.782.220~r99552/src/content/browser/renderer_host/resource_dispatcher_host_request_info.cc <==
// Copyright (c) 2010 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "content/browser/renderer_host/resource_dispatcher_host_request_info.h"

#include "chrome/browser/ssl/ssl_client_auth_handler.h"
#include "chrome/browser/ui/login/login_prompt.h"
#include "content/browser/renderer_host/resource_handler.h"
#include "webkit/blob/blob_data.h"

ResourceDispatcherHostRequestInfo::ResourceDispatcherHostRequestInfo(
    ResourceHandler* handler,
    ChildProcessInfo::ProcessType process_type,
    int child_id,
    int route_id,
    int origin_pid,
    int request_id,
    ResourceType::Type resource_type,
    uint64 upload_size,
    bool is_download,
    bool allow_download,
    bool has_user_gesture,
    const content::ResourceContext* context)
    : resource_handler_(handler),
      cross_site_handler_(NULL),
      process_type_(process_type),
      child_id_(child_id),
      route_id_(route_id),
      origin_pid_(origin_pid),
      request_id_(request_id),
      pending_data_count_(0),
      is_download_(is_download),
      allow_download_(allow_download),
      has_user_gesture_(has_user_gesture),
      pause_count_(0),
      resource_type_(resource_type),
      last_load_state_(net::LOAD_STATE_IDLE),
      upload_size_(upload_size),
      last_upload_position_(0),
      waiting_for_upload_progress_ack_(false),
      memory_cost_(0),
      context_(context),
      is_paused_(false),
      called_on_response_started_(false),
      has_started_reading_(false),
      paused_read_bytes_(0) {
}

ResourceDispatcherHostRequestInfo::~ResourceDispatcherHostRequestInfo() {
  resource_handler_->OnRequestClosed();
}

void ResourceDispatcherHostRequestInfo::set_login_handler(LoginHandler* lh) {
  login_handler_ = lh;
}

void ResourceDispatcherHostRequestInfo::set_ssl_client_auth_handler(
    SSLClientAuthHandler* s) {
  ssl_client_auth_handler_ = s;
}

void ResourceDispatcherHostRequestInfo::set_requested_blob_data(
    webkit_blob::BlobData* data) {
  requested_blob_data_ = data;
}

==> chromium-browser_14.0.835.202~r103287.orig.tar.bz2: chromium-14.0.835.202~r103287/src/content/browser/renderer_host/resource_dispatcher_host_request_info.cc <==
// Copyright (c) 2011 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#include "content/browser/renderer_host/resource_dispatcher_host_request_info.h"

#include "content/browser/renderer_host/resource_dispatcher_host_login_delegate.h"
#include "content/browser/renderer_host/resource_handler.h"
#include "content/browser/ssl/ssl_client_auth_handler.h"
#include "webkit/blob/blob_data.h"

ResourceDispatcherHostRequestInfo::ResourceDispatcherHostRequestInfo(
    ResourceHandler* handler,
    ChildProcessInfo::ProcessType process_type,
    int child_id,
    int route_id,
    int origin_pid,
    int request_id,
    bool is_main_frame,
    int64 frame_id,
    ResourceType::Type resource_type,
    uint64 upload_size,
    bool is_download,
    bool allow_download,
    bool has_user_gesture,
    const content::ResourceContext* context)
    : resource_handler_(handler),
      cross_site_handler_(NULL),
      process_type_(process_type),
      child_id_(child_id),
      route_id_(route_id),
      origin_pid_(origin_pid),
      request_id_(request_id),
      is_main_frame_(is_main_frame),
      frame_id_(frame_id),
      pending_data_count_(0),
      is_download_(is_download),
      allow_download_(allow_download),
      has_user_gesture_(has_user_gesture),
      pause_count_(0),
      resource_type_(resource_type),
      last_load_state_(net::LOAD_STATE_IDLE),
      upload_size_(upload_size),
      last_upload_position_(0),
      waiting_for_upload_progress_ack_(false),
      memory_cost_(0),
      context_(context),
      is_paused_(false),
      called_on_response_started_(false),
      has_started_reading_(false),
      paused_read_bytes_(0) {
}

ResourceDispatcherHostRequestInfo::~ResourceDispatcherHostRequestInfo() {
  resource_handler_->OnRequestClosed();
}

void ResourceDispatcherHostRequestInfo::set_login_delegate(
    ResourceDispatcherHostLoginDelegate* ld) {
  login_delegate_ = ld;
}

void ResourceDispatcherHostRequestInfo::set_ssl_client_auth_handler(
    SSLClientAuthHandler* s) {
  ssl_client_auth_handler_ = s;
}

void ResourceDispatcherHostRequestInfo::set_requested_blob_data(
    webkit_blob::BlobData* data) {
  requested_blob_data_ = data;
}
